[polly] r268223 - Rename Conjuncts -> Disjunctions. NFC.

Michael Kruse via llvm-commits llvm-commits at lists.llvm.org
Mon May 2 05:25:19 PDT 2016


Author: meinersbur
Date: Mon May  2 07:25:18 2016
New Revision: 268223

URL: http://llvm.org/viewvc/llvm-project?rev=268223&view=rev
Log:
Rename Conjuncts -> Disjunctions. NFC.

The check for complexity compares the number of polyhedra in a set,
which are combined by disjunctions (union, "OR"),
not conjunctions (intersection, "AND").

Modified:
    polly/trunk/lib/Analysis/ScopInfo.cpp
    polly/trunk/lib/CodeGen/IslNodeBuilder.cpp
    polly/trunk/lib/Support/SCEVAffinator.cpp

Modified: polly/trunk/lib/Analysis/ScopInfo.cpp
URL: http://llvm.org/viewvc/llvm-project/polly/trunk/lib/Analysis/ScopInfo.cpp?rev=268223&r1=268222&r2=268223&view=diff
==============================================================================
--- polly/trunk/lib/CodeGen/IslNodeBuilder.cpp (original)
+++ polly/trunk/lib/CodeGen/IslNodeBuilder.cpp Mon May  2 07:25:18 2016
@@ -52,7 +52,7 @@ using namespace llvm;
 // More complex access ranges will result in very high compile time and are also
 // unlikely to result in good code. This value is very high and should only
 // trigger for corner cases (e.g., the "dct_luma" function in h264, SPEC2006).
-static int const MaxConjunctsInAccessRange = 80;
+static int const MaxDisjunctionsInAccessRange = 80;
 
 __isl_give isl_ast_expr *
 IslNodeBuilder::getUpperBound(__isl_keep isl_ast_node *For,
@@ -925,7 +925,7 @@ bool IslNodeBuilder::materializeParamete
 Value *IslNodeBuilder::preloadUnconditionally(isl_set *AccessRange,
                                               isl_ast_build *Build,
                                               Instruction *AccInst) {
-  if (isl_set_n_basic_set(AccessRange) > MaxConjunctsInAccessRange) {
+  if (isl_set_n_basic_set(AccessRange) > MaxDisjunctionsInAccessRange) {
     isl_set_free(AccessRange);
     return nullptr;
   }

Modified: polly/trunk/lib/Support/SCEVAffinator.cpp
URL: http://llvm.org/viewvc/llvm-project/polly/trunk/lib/Support/SCEVAffinator.cpp?rev=268223&r1=268222&r2=268223&view=diff
==============================================================================
--- polly/trunk/lib/Support/SCEVAffinator.cpp (original)
+++ polly/trunk/lib/Support/SCEVAffinator.cpp Mon May  2 07:25:18 2016
@@ -34,7 +34,7 @@ static cl::opt<bool> IgnoreIntegerWrappi
 // The maximal number of basic sets we allow during the construction of a
 // piecewise affine function. More complex ones will result in very high
 // compile time.
-static int const MaxConjunctsInPwAff = 100;
+static int const MaxDisjunctionsInPwAff = 100;
 
 // The maximal number of bits for which a zero-extend is modeled precisely.
 static unsigned const MaxZextSmallBitWidth = 7;
@@ -71,7 +71,7 @@ static __isl_give PWACtx copyPWACtx(cons
 static bool isTooComplex(PWACtx &PWAC) {
   unsigned NumBasicSets = 0;
   isl_pw_aff_foreach_piece(PWAC.first, addNumBasicSets, &NumBasicSets);
-  if (NumBasicSets <= MaxConjunctsInPwAff)
+  if (NumBasicSets <= MaxDisjunctionsInPwAff)
     return false;
   freePWACtx(PWAC);
   return true;




More information about the llvm-commits mailing list
--- polly/trunk/lib/Analysis/ScopInfo.cpp (original)
+++ polly/trunk/lib/Analysis/ScopInfo.cpp Mon May  2 07:25:18 2016
@@ -66,7 +66,7 @@ STATISTIC(RichScopFound, "Number of Scop
 // The maximal number of basic sets we allow during domain construction to
 // be created. More complex scops will result in very high compile time and
 // are also unlikely to result in good code
-static int const MaxConjunctsInDomain = 20;
+static int const MaxDisjunctionsInDomain = 20;
 
 static cl::opt<bool> PollyRemarksMinimal(
     "polly-remarks-minimal",
@@ -1340,12 +1340,13 @@ buildConditionSets(ScopStmt &Stmt, Value
 
   isl_set *AlternativeCondSet = nullptr;
   bool ToComplex =
-      isl_set_n_basic_set(ConsequenceCondSet) >= MaxConjunctsInDomain;
+      isl_set_n_basic_set(ConsequenceCondSet) >= MaxDisjunctionsInDomain;
 
   if (!ToComplex) {
     AlternativeCondSet = isl_set_subtract(isl_set_copy(Domain),
                                           isl_set_copy(ConsequenceCondSet));
-    ToComplex = isl_set_n_basic_set(AlternativeCondSet) >= MaxConjunctsInDomain;
+    ToComplex =
+        isl_set_n_basic_set(AlternativeCondSet) >= MaxDisjunctionsInDomain;
   }
 
   if (ToComplex) {
@@ -2095,7 +2096,7 @@ static isl_stat buildMinMaxAccess(__isl_
 
   Set = isl_set_remove_divs(Set);
 
-  if (isl_set_n_basic_set(Set) >= MaxConjunctsInDomain) {
+  if (isl_set_n_basic_set(Set) >= MaxDisjunctionsInDomain) {
     isl_set_free(Set);
     return isl_stat_error;
   }
@@ -2419,9 +2420,9 @@ void Scop::propagateInvalidStmtDomains(R
       unsigned NumConjucts = isl_set_n_basic_set(SuccInvalidDomain);
       SuccStmt->setInvalidDomain(SuccInvalidDomain);
 
       // Check if the maximal number of domain conjuncts was reached.
       // In case this happens we will bail.
-      if (NumConjucts < MaxConjunctsInDomain)
+      if (NumConjucts < MaxDisjunctionsInDomain)
         continue;
 
       isl_set_free(InvalidDomain);
@@ -2597,9 +2598,9 @@ bool Scop::buildDomainsWithBranchConstra
         SuccDomain = CondSet;
       }
 
       // Check if the maximal number of domain conjuncts was reached.
       // In case this happens we will clean up and bail.
-      if (isl_set_n_basic_set(SuccDomain) < MaxConjunctsInDomain)
+      if (isl_set_n_basic_set(SuccDomain) < MaxDisjunctionsInDomain)
         continue;
 
       invalidate(COMPLEXITY, DebugLoc());
@@ -3280,7 +3281,7 @@ void Scop::addInvariantLoads(ScopStmt &S
   isl_set *DomainCtx = isl_set_params(Stmt.getDomain());
   DomainCtx = isl_set_subtract(DomainCtx, StmtInvalidCtx);
 
-  if (isl_set_n_basic_set(DomainCtx) >= MaxConjunctsInDomain) {
+  if (isl_set_n_basic_set(DomainCtx) >= MaxDisjunctionsInDomain) {
     auto *AccInst = InvMAs.front()->getAccessInstruction();
     invalidate(COMPLEXITY, AccInst->getDebugLoc());
     isl_set_free(DomainCtx);
@@ -2419,9 +2420,9 @@ void Scop::propagateInvalidStmtDomains(R
       SuccStmt->setInvalidDomain(SuccInvalidDomain);
 
-      // Check if the maximal number of domain conjuncts was reached.
+      // Check if the maximal number of domain disjunctions was reached.
       // In case this happens we will bail.
@@ -2597,9 +2598,9 @@ bool Scop::buildDomainsWithBranchConstra
       }
 
-      // Check if the maximal number of domain conjuncts was reached.
+      // Check if the maximal number of domain disjunctions was reached.
       // In case this happens we will clean up and bail.

Modified: polly/trunk/lib/CodeGen/IslNodeBuilder.cpp
URL: http://llvm.org/viewvc/llvm-project/polly/trunk/lib/CodeGen/IslNodeBuilder.cpp?rev=268223&r1=268222&r2=268223&view=diff
==============================================================================